@@ -264,8 +264,14 @@ def is_X11():
         return True
 
 def is_Wayland():
-    return os.environ.get("GDK_BACKEND", "")!="x11" and (
-        os.environ.get("WAYLAND_DISPLAY") or os.environ.get("XDG_SESSION_TYPE")=="wayland"
+    return _is_Wayland(os.environ)
+
+def _is_Wayland(env):
+    backend = env.get("GDK_BACKEND", "")
+    if backend=="wayland":
+        return True
+    return backend!="x11" and (
+        bool(env.get("WAYLAND_DISPLAY")) or env.get("XDG_SESSION_TYPE")=="wayland"
         )
 
 
@@ -374,6 +380,9 @@ def is_unity():
     return os.environ.get("XDG_CURRENT_DESKTOP", "").lower().find("unity")>=0
 
 def is_gnome():
+    if os.environ.get("XDG_SESSION_DESKTOP", "").split("-", 1)[0] in ("i3", "ubuntu", ):
+        #"i3-gnome" is not really gnome... ie: the systray does work!
+        return False
     return os.environ.get("XDG_CURRENT_DESKTOP", "").lower().find("gnome")>=0
 
 def is_kde():
